##  Overview
**Note**
A new import experience is available to all users from February 26, 2026. The updated interface offers improved stability and allows you to minimize the import window to continue working in other areas of the application while the file is processed and uploaded. For details, see [Step 3: Upload the File, Review, and Correct Errors](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a86917a441014872eecad909f5e9e__step_3_upload_the_file_review_and_correct_errors).
The option to revert to the classic import experience remains available in the import dialog until March 16, 2026. After this date, the new import experience is the only option.
SAP LeanIX’s import feature allows users to efficiently add, update, and delete fact sheet data through an Excel file. Making use of the export functionality, you can create a template file with columns for each needed fact sheet attribute, fill or update them and import the file back. Import functionality allows you to bulk update seamlessly, ensuring that all necessary fact sheet fields are populated and up-to-date.
Using the import function, you can do the following:
  * Update existing fact sheet values
  * Delete fact sheet values
  * Populate empty attributes of fact sheets
  * Create new fact sheets
  * Archive fact sheets
